DistributedSigningCoordinator class abstract final

Runs threshold signing with officers submitting partials to a coordinator.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

run({required List<Share> shares, required Uint8List message, SigningJobCoordinator? coordinator, Uint8List? context}) → Future<Uint8List>
Each shares entry signs in-process and submits to coordinator.