PqthHeader class final

Parsed 8-byte PQTH object header.

Constructors

PqthHeader({required int version, required PqthObjectKind kind, required SchemeId scheme})
Creates a header.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → PqthObjectKind
Object kind.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → SchemeId
Scheme identifier.
final
version → int
Format version byte.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Encodes the fixed header.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Uint8List bytes) → PqthHeader
Parses and validates a header from the start of bytes.