InMemoryCeremonyRelay class final
In-memory relay for tests and local multi-process prototypes.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchInbox(
{required String ceremonyId, required int recipientIndex}) → Future< List< Uint8List> > -
Returns wire bytes addressed to
recipientIndex(or broadcast if null).override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
{required String ceremonyId, required int senderIndex, required Uint8List wireBytes, int? recipientIndex}) → Future< void> -
Publishes one outbound DKG envelope.
override
-
resetCeremony(
String ceremonyId) → void - Clears a ceremony bucket (tests).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited