PqthHeader class final
Parsed 8-byte PQTH object header.
Constructors
- PqthHeader({required int version, required PqthObjectKind kind, required SchemeId scheme})
-
Creates a header.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List - Encodes the fixed header.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Uint8List bytes) → PqthHeader -
Parses and validates a header from the start of
bytes.